@@ -1,4 +1,4 @@
-import os
+import os.path as os_path
 import pathlib
 import pkg_resources
 import signal
@@ -14,6 +14,7 @@ import numpy
 import scipy
 
 from PyQt5 import uic, QtCore, QtGui, QtWidgets
+from PyQt5.QtCore import QStandardPaths
 import pyqtgraph as pg
 
 from . import analysis
@@ -27,6 +28,7 @@ from . import quick_view
 from . import update
 from . import widgets
 
+from ..extensions import ExtensionManager
 from .. import pipeline
 from .. import session
 
@@ -42,7 +44,7 @@ pg.setConfigOption("imageAxisOrder", "row-major")
 
 # set Qt icon theme search path
 QtGui.QIcon.setThemeSearchPaths([
-    os.path.join(pkg_resources.resource_filename("shapeout2", "img"),
+    os_path.join(pkg_resources.resource_filename("shapeout2", "img"),
                  "icon-theme")])
 QtGui.QIcon.setThemeName(".")
 
@@ -80,6 +82,19 @@ class ShapeOut2(QtWidgets.QMainWindow):
         dclab.rtdc_dataset.fmt_dcor.APIHandler.add_api_key(api_key)
         #: Analysis pipeline
         self.pipeline = pipeline.Pipeline()
+        #: Extensions
+        store_path = os_path.join(
+            QStandardPaths.writableLocation(
+                QStandardPaths.AppLocalDataLocation), "extensions")
+        try:
+            self.extensions = ExtensionManager(store_path)
+        except BaseException:
+            QtWidgets.QMessageBox.warning(
+                self,
+                "Extensions automatically disabled",
+                "Some extensions could not be loaded and were disabled:\n\n"
+                + traceback.format_exc(),
+                )
         # GUI
         self.setWindowTitle("Shape-Out {}".format(__version__))
         # Disable native menu bar (e.g. on Mac)
@@ -87,6 +102,8 @@ class ShapeOut2(QtWidgets.QMainWindow):
         # File menu
         self.actionLoadDataset.triggered.connect(self.add_dataslot)
         self.actionLoadDCOR.triggered.connect(self.on_action_dcor)
+        self.actionClearDatasets.triggered.connect(
+            self.on_action_clear_datasets)
         self.actionClearSession.triggered.connect(self.on_action_clear)
         self.actionOpenSession.triggered.connect(self.on_action_open)
         self.actionQuit.triggered.connect(self.on_action_quit)
@@ -151,6 +168,8 @@ class ShapeOut2(QtWidgets.QMainWindow):
         # polygon filter creation
         self.widget_ana_view.widget_filter.request_new_polygon_filter.connect(
             self.on_new_polygon_filter)
+        self.widget_quick_view.polygon_filter_about_to_be_deleted.connect(
+            self.on_remove_polygon_filter_from_pipeline)
         self.widget_quick_view.polygon_filter_created.connect(
             self.widget_ana_view.widget_filter.update_polygon_filters)
         self.widget_quick_view.polygon_filter_modified.connect(
@@ -239,7 +258,9 @@ class ShapeOut2(QtWidgets.QMainWindow):
         # update BlockMatrix
         if self.sender() != self.block_matrix:
             # Update BlockMatrix
+            self.setUpdatesEnabled(False)
             self.block_matrix.adopt_pipeline(pipeline_state)
+            self.setUpdatesEnabled(True)
         # trigger redraw
         self.block_matrix.update()
         # Invalidate block matrix elements that do not make sense due to
@@ -371,6 +392,7 @@ class ShapeOut2(QtWidgets.QMainWindow):
 
         slot_ids = []
         # Create Dataslot instance and update block matrix
+        self.setUpdatesEnabled(False)
         for fn in fnames:
             if is_dcor:
                 path = fn
@@ -383,6 +405,8 @@ class ShapeOut2(QtWidgets.QMainWindow):
             slot_id = self.pipeline.add_slot(path=path)
             self.block_matrix.add_dataset(slot_id=slot_id)
             slot_ids.append(slot_id)
+        self.setUpdatesEnabled(True)
+        self.repaint()
 
         # Update box filter limits
         self.widget_ana_view.widget_filter.update_box_ranges()
@@ -436,18 +460,26 @@ class ShapeOut2(QtWidgets.QMainWindow):
         else:
             e.ignore()
 
+    @widgets.show_wait_cursor
     def dropEvent(self, e):
         """Add dropped files to view"""
         urls = e.mimeData().urls()
-        pathlist = []
-        for ff in urls:
-            pp = pathlib.Path(ff.toLocalFile())
-            if pp.is_dir():
-                pathlist += list(pp.rglob("*.rtdc"))
-            elif pp.suffix == ".rtdc":
-                pathlist.append(pp)
-        if pathlist:
-            self.add_dataslot(paths=sorted(pathlist))
+        if urls:
+            pathlist = []
+            is_dcor = bool(urls[0].host())
+            for ff in urls:
+                if is_dcor:
+                    # DCOR data
+                    pathlist.append(ff.toString())
+                else:
+                    pp = pathlib.Path(ff.toLocalFile())
+                    if pp.is_dir():
+                        pathlist += list(pp.rglob("*.rtdc"))
+                    elif pp.suffix == ".rtdc":
+                        pathlist.append(pp)
+                    pathlist = sorted(pathlist)
+            if pathlist:
+                self.add_dataslot(paths=pathlist, is_dcor=is_dcor)
 
     def init_analysis_view(self):
         sub = widgets.MDISubWindowWOButtons(self)
@@ -569,16 +601,33 @@ class ShapeOut2(QtWidgets.QMainWindow):
         if assume_yes:
             yes = True
         else:
-            buttonReply = QtWidgets.QMessageBox.question(
+            button_reply = QtWidgets.QMessageBox.question(
                 self, 'Clear Session', "All progress will be lost. Continue?",
                 QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No,
                 QtWidgets.QMessageBox.No)
-            yes = buttonReply == QtWidgets.QMessageBox.Yes
+            yes = button_reply == QtWidgets.QMessageBox.Yes
         if yes:
             session.clear_session(self.pipeline)
             self.reload_pipeline()
         return yes
 
+    @QtCore.pyqtSlot()
+    def on_action_clear_datasets(self, assume_yes=False):
+        if assume_yes:
+            yes = True
+        else:
+            button_reply = QtWidgets.QMessageBox.question(
+                self, 'Clear Datasets',
+                "Remove all datasets from this session?",
+                QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No,
+                QtWidgets.QMessageBox.No)
+            yes = button_reply == QtWidgets.QMessageBox.Yes
+        if yes:
+            for slot_id in self.pipeline.slot_ids:
+                self.pipeline.remove_slot(slot_id)
+            self.reload_pipeline()
+        return yes
+
     @QtCore.pyqtSlot()
     def on_action_dcor(self):
         """Show the DCOR import dialog"""
@@ -663,6 +712,8 @@ class ShapeOut2(QtWidgets.QMainWindow):
     def on_action_preferences(self):
         """Show the DCOR import dialog"""
         dlg = preferences.Preferences(self)
+        dlg.feature_changed.connect(self.plots_changed)
+        dlg.feature_changed.connect(self.on_quickview_refresh)
         dlg.exec()
 
     @QtCore.pyqtSlot()
@@ -706,6 +757,13 @@ class ShapeOut2(QtWidgets.QMainWindow):
                                           "Software",
                                           sw_text)
 
+    @QtCore.pyqtSlot(int)
+    def on_remove_polygon_filter_from_pipeline(self, pf_id):
+        """Remove a polygon filter from all filters in the pipeline"""
+        for filt in self.pipeline.filters:
+            if pf_id in filt.polylist:
+                filt.polylist.remove(pf_id)
+
     @widgets.show_wait_cursor
     @QtCore.pyqtSlot()
     def on_data_matrix(self):
