@@ -1,4 +1,3 @@
-import dclab
 import numpy as np
 from PyQt5 import QtCore
 import pyqtgraph as pg
@@ -44,7 +43,9 @@ class QuickViewScatterWidget(SimplePlotWidget):
         # let view box update self.poly_line_roi
         self._view_box.add_poly_vertex.connect(self.add_poly_vertex)
 
-    def activate_poly_mode(self, points=[]):
+    def activate_poly_mode(self, points=None):
+        if points is None:
+            points = []
         if self.poly_line_roi is None:
             self.poly_line_roi = pg.PolyLineROI([], closed=True)
             self.poly_line_roi.setPen("k")
@@ -116,16 +117,10 @@ class QuickViewScatterWidget(SimplePlotWidget):
         # set data
         self.setData(x, y, brush=brush)
         # set axes labels (replace with user-defined flourescence names)
-        left = dclab.dfn.get_feature_label(self.yax)
-        bottom = dclab.dfn.get_feature_label(self.xax)
-        for key in self.slot.fl_name_dict:
-            if key in left:
-                left = left.replace(key, self.slot.fl_name_dict[key])
-                break
-        for key in self.slot.fl_name_dict:
-            if key in bottom:
-                bottom = bottom.replace(key, self.slot.fl_name_dict[key])
-                break
+        left = pipeline_plot.get_axis_label_from_feature(
+            self.yax, slot_state=self.slot.__getstate__())
+        bottom = pipeline_plot.get_axis_label_from_feature(
+            self.xax, slot_state=self.slot.__getstate__())
         self.plotItem.setLabels(left=left, bottom=bottom)
 
         # Force updating the plot item size, otherwise axes labels
