@@ -2,7 +2,7 @@ import pyqtgraph as pg
 
 
 class ShapeOutColorBarItem(pg.ColorBarItem):
-    def __init__(self, yoffset, height, label, *args, **kwargs):
+    def __init__(self, yoffset, height, label, colorMap, **kwargs):
         """pg.ColorBarItem modified for Shape-Out
 
         - Added option to define height
@@ -10,11 +10,15 @@ class ShapeOutColorBarItem(pg.ColorBarItem):
         - show the label on the right-hand axis
         - increase the contents margins
         """
-        super(ShapeOutColorBarItem, self).__init__(*args, **kwargs)
-
-        for key in ['left', 'top', 'bottom']:
-            axis = self.getAxis(key)
-            axis.setTicks([])
+        super(ShapeOutColorBarItem, self).__init__(
+            colorMap=colorMap,
+            # TODO: Removing `cmap=colorMap` results in grayscale colormaps.
+            # https://github.com/ZELLMECHANIK-DRESDEN/ShapeOut2/issues/109
+            # This does not make sense at all. But maybe some mysteries are
+            # meant to stay hidden indefinitely. Maybe in July 2022, when
+            # pyqtgraph drops the "cmap" argument, it will just work...
+            cmap=colorMap,
+            **kwargs)
 
         # show label on right side
         self.axis.setLabel(label)
